<?php

// Version: 1.1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;
	
	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	$settings['use_default_images'] = 'never';
	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;
	
	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = false;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum" />
		<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>		

		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';
	
	if (empty($settings['select_css'])) {
	$settings['color_css'] = 'blue'; 
	} else {
	$settings['color_css'] = $settings['select_css']; }	

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/style.css?fin11" />
			  <!--[if lte IE 7]>
	 <link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/ie.css?fin11"  />
		  <![endif]-->
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/', $settings['color_css'] ,'_ceiling.css?fin11" />	
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
	
	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "" : "");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';
	
	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>
		
		</head>
<body>';

		 echo '<div class="extnation">';
		
			if (empty($settings['header_logo_name']))
		 {
		echo '<div class="headtop">', $context['forum_name'] ,'</div>';
		}
		else
		{
			echo '
		 <div id="headerimg"><center><img src="', $settings['default_theme_url'],'/images/', $settings['header_logo_name'], '" alt="', $context['forum_name'], '" </img></center></div>';
		 }
		
	  echo '<div id="upshrinkHeader"', empty($options['collapse_header']) ? '' : ' style="display:none;"', '>';		

	echo '<div class="indinfo">';
		
					  echo '<div id="indexavatar">
				<div id="proavind">';
	if (!empty($context['user']['avatar']))
		{	
			echo '', $context['user']['avatar']['image'] ,'';
		 }	
	elseif ($context['user']['is_guest'])
		echo '<img src="', $settings['theme_url'], '/images/noavatar.gif" alt="" />';
		
		echo '</div>
		</div>';
	
		//search
		echo '<div class="hdsearch"><ul class="srch"><li>
<form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
					<em><input type="text" class="srcm" name="search" value="" /></em>&nbsp;
					<em><input type="submit" name="submit" value="', $txt[182], '" /></em>
						<input type="hidden" name="advanced" value="0" />';

	// Search within current topic?
	if (!empty($context['current_topic']))
		echo '<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
		// If we're on a certain board, limit it to this board ;).
	elseif (!empty($context['current_board']))
		echo '<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';
		
	echo '</form>
	</li></ul></div>';	
		//search
		
	if($context['user']['is_logged'])
	{
			
	 echo '<div style="height:45px;">&nbsp;', $txt['hello_member_ndt'], ' <b class="largetext">', $context['user']['name'] , '</b>';
	 if ($context['allow_pm'])
				 {
			echo ', ', $txt[152], ' <a href="', $scripturl, '?action=pm">', $context['user']['messages'], ' ', $context['user']['messages'] != 1 ? $txt[153] : $txt[471], '</a>', $txt['newmessages4'], ' ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'];
				 }		 
	echo '<br />&nbsp;<a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a>
	<br />&nbsp;<a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a>';
		

		echo '</div>';
	}
			// Otherwise they're a guest - send them a lovely greating...
	else 
	 {
		echo '<div style="height:45px;">&nbsp;', $txt['welcome_guest'], '', $txt['welcome_guest_activate'] ,'</div>';
	 }
		
			// Now, onto our second set of info, are they logged in again?
	if ($context['user']['is_logged'])
	 {		
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
		{
			echo '&nbsp;<b>', $txt[616], '</b><br />';								

		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '&nbsp;', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '';
		  } 

	 }
	
	// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '
		<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
		<div style="float:left;">
<ul class="srchlogin"><li>
								<form action="', $scripturl, '?action=login2" accept-charset="', $context['character_set'], '" method="post" class="middletext" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
		<em><input type="text" name="user" class="srcm2" size="10" /></em><br />
		<em><input type="password" name="passwrd" class="srcm2" size="10" /></em>
									<select name="cookielength">
										<option value="60">', $txt['smf53'], '</option>
										<option value="1440">', $txt['smf47'], '</option>
										<option value="10080">', $txt['smf48'], '</option>
										<option value="43200">', $txt['smf49'], '</option>
										<option value="-1" selected="selected">', $txt['smf50'], '</option>
									</select>
									<input type="submit" value="', $txt[34], '" /><br />
									
									<input type="hidden" name="hash_passwrd" value="" />
								</form>
		</li></ul></div>';
	}	
				 
		  echo '<div class="indnews">';		 
		
	if (!empty($settings['enable_news']))
		echo '<span class="smalltext"><b>', $txt[102], '</b>: ', $context['random_news_line'], '</span>';

	  echo '</div>';
	
	echo '</div>';
	
	//on-off end
	 echo '</div>
	 </div>';
	 
	 echo '<div class="clear"></div>
	 <div class="extnation">
		<div style="float:right;color:#000;">', $context['current_time'], '<a href="" onclick="shrinkHeader(!current_header); return false;"><img id="upshrink" src="', $settings['images_url'], '/ceiling/', empty($options['collapse_header']) ? 'upshrink.gif' : 'upshrink2.gif', '" alt="*" title="', $txt['upshrink_description'], '" align="bottom" style="margin:0 6px;" /></a></div>
		</div>';

	 echo '<div class="clear"></div><div class="extnation2">
	<div id="prosomenu">	 
		<ul>';
		template_menu();
	echo '</ul></div>	
	</div><div class="clear"></div>';  
	  
	// The main content should go here.	
	echo '<div class="extnation">';
	
	echo '<div class="external">	
	<div class="top"><div class="topmid"><div class="topc"></div></div></div>
	  <div class="mid"><div class="midc"><div class="mids">';

				
			echo '<div class="bodyarea l">';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;
		// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!

	// The End oeoeoeoeoeoeoeoe

echo '
<div class="footerpower">
		<a href="http://www.mysql.com/" target="_blank">', $txt['powered_by_mysql'], ' |</a>
		<a href="http://www.php.net/" target="_blank">', $txt['powered_by_php'], ' |</a>
		<a href="http://validator.w3.org/check/referer" target="_blank">', $txt['valid_xhtml'], ' |</a>
		<a href="http://jigsaw.w3.org/css-validator/check/referer" target="_blank">', $txt['valid_css'], ' |</a>
		<a href="http://w3tableless.com?uri=" target="_blank">Valid Tableless! |</a>
		<a href="http://custom.simplemachines.org/themes/index.php?lemma=315" target="_blank">Remorse Ceiling Theme</a>
		<br />', theme_copyright(), '';
				 
							// Show the load time?
	if ($context['show_load_time'])
		echo '<div class="loadtime">
		', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</div>';			
							 
echo '</div>
</div>';	

	echo '  
	</div></div></div>
 <div class="bot"><div class="botmid"><div class="botc"></div></div></div>
  </div>  
 </div>

</body></html>';

}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '<span class="wsp">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;&#187;&nbsp;';
	}

	echo '</span>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $modSettings, $txt;

	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'learnbase', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';
	mbt();
	
				foreach ($context['menu'] as $i => $mbt)
				{	  
					if ($i == $current_action)
					 echo '<li id="selected">', $mbt, '</li>';
					  else
					 echo '<li>', $mbt, '</li>';	
				 }				
}

function mbt()	 
{
  global $context, $scripturl, $txt; 
  
  $context['menu'] = array();  
  
  $context['menu']['home'] = '<a href="'. $scripturl. '"><span>'. $txt[103]. '</span></a>';
  $context['menu']['help'] = '<a href="'. $scripturl. '?action=help"><span>'. $txt[119]. '</span></a>';
  
  if ($context['allow_search'])
  $context['menu']['search'] = '<a href="'. $scripturl. '?action=search"><span>'. $txt[182]. '</span></a>';
  
  if ($context['allow_admin'])
  $context['menu']['admin'] = '<a href="'. $scripturl. '?action=admin"><span>'. $txt[2]. '</span></a>';
  
  if ($context['allow_edit_profile'])
  $context['menu']['profile'] = '<a href="'. $scripturl. '?action=profile"><span>'. $txt[79]. '</span></a>';
  
  if ($context['allow_calendar'])
  $context['menu']['calendar'] = '<a href="'. $scripturl. '?action=calendar"><span>'. $txt['calendar24']. '</span></a>';
  
  if ($context['user']['is_guest'])
	{	
	  $context['menu']['login'] = '<a href="'. $scripturl. '?action=login"><span>'. $txt[34]. '</span></a>'; 
	  $context['menu']['register'] = '<a href="'. $scripturl. '?action=register"><span>'. $txt[97]. '</span></a>';
	}
	
  else 
	  $context['menu']['logout'] ='<a href="'. $scripturl. '?action=logout;sesc='. $context['session_id'].'"><span>'. $txt[108]. '</span></a>';
}

?>